@@ -75,10 +75,14 @@ class AnalysisTechnique(str, Enum):
     OTHER = 'other'
 
 
-@serializable.serializable_class
+@serializable.serializable_class(ignore_unknown_during_deserialization=True)
 class Method:
     """
     Represents a method used to extract and/or analyze evidence.
+
+    .. note::
+        See the CycloneDX Schema definition:
+        https://cyclonedx.org/docs/1.6/json/#components_items_evidence_identity_oneOf_i0_items_methods
     """
 
     def __init__(
@@ -181,7 +185,7 @@ class _IdentityToolRepositorySerializationHelper(serializable.helpers.BaseHelper
         return [BomRef(value=t.get('ref')) for t in o]
 
 
-@serializable.serializable_class
+@serializable.serializable_class(ignore_unknown_during_deserialization=True)
 class Identity:
     """
     Our internal representation of the `identityType` complex type.
@@ -288,7 +292,7 @@ class Identity:
             f' methods={self.methods}, tools={self.tools}>'
 
 
-@serializable.serializable_class
+@serializable.serializable_class(ignore_unknown_during_deserialization=True)
 class Occurrence:
     """
     Our internal representation of the `occurrenceType` complex type.
@@ -423,7 +427,7 @@ class Occurrence:
         return f'<Occurrence location={self.location}, line={self.line}, symbol={self.symbol}>'
 
 
-@serializable.serializable_class
+@serializable.serializable_class(ignore_unknown_during_deserialization=True)
 class CallStackFrame:
     """
     Represents an individual frame in a call stack.
@@ -567,7 +571,7 @@ class CallStackFrame:
                f' line={self.line}, column={self.column}, full_filename={self.full_filename}>'
 
 
-@serializable.serializable_class
+@serializable.serializable_class(ignore_unknown_during_deserialization=True)
 class CallStack:
     """
     Our internal representation of the `callStackType` complex type.
@@ -622,7 +626,7 @@ class CallStack:
         return f'<CallStack frames={len(self.frames)}>'
 
 
-@serializable.serializable_class
+@serializable.serializable_class(ignore_unknown_during_deserialization=True)
 class ComponentEvidence:
     """
     Our internal representation of the `componentEvidenceType` complex type.
