@@ -16,9 +16,10 @@
 # Copyright (c) OWASP Foundation. All Rights Reserved.
 
 
+from collections.abc import Callable
 from json import loads as json_loads
 from os.path import join
-from typing import Any, Callable
+from typing import Any
 from unittest import TestCase
 from unittest.mock import patch
 
@@ -116,7 +117,7 @@ class TestDeserializeJson(TestCase, SnapshotMixin, DeepCompareMixin):
 
     def test_regression_issue690(self) -> None:
         """
-        regressio test for issue#690.
+        regression test for issue#690.
         see https://github.com/CycloneDX/cyclonedx-python-lib/issues/690
         """
         json_file = join(OWN_DATA_DIRECTORY, 'json',
